==> derby-0.1.0.tgz: package/lib/derby.js <==
var Page, Router, Static, View, loader, racer, serverMock;
var __slice = Array.prototype.slice;
racer = require('racer');
View = require('./View.server');
loader = require('./loader');
Router = require('express/lib/router');
serverMock = {
  enabled: function() {
    return false;
  }
};
Page = function(view, res, model) {
  this.view = view;
  this.res = res;
  this.model = model;
};
Page.prototype = {
  render: function(ctx, status) {
    return this.view.render(this.res, this.model, ctx, status);
  },
  redirect: function(url, status) {
    return this.res.redirect(url, status);
  }
};
Static = function(root) {
  this.root = root;
  this.views = {};
};
Static.prototype = {
  render: function(name, res, model, ctx, status) {
    var view;
    if (!(view = this.views[name])) {
      view = this.views[name] = new View;
      view._root = this.root;
      view._clientName = name;
    }
    return view.render(res, model, ctx, status, true);
  }
};
module.exports = {
  options: {},
  version: '0.1alpha',
  configure: function(options) {
    this.options = options;
  },
  createApp: function(appModule) {
    var appExports, routes, session, setStore, store, view;
    appExports = appModule.exports;
    appExports.view = view = new View;
    appExports.render = function(res, model, ctx, status) {
      return view.render(res, model, ctx, status);
    };
    appExports.ready = function() {};
    store = null;
    session = null;
    appExports._setStore = setStore = function(_store) {
      if (session != null) {
        session._setStore(_store);
      }
      return store = _store;
    };
    appExports.createStore = function(options) {
      return setStore(racer.createStore(options));
    };
    appExports.session = function() {
      return session = racer.session(store);
    };
    routes = [];
    ['get', 'post', 'put', 'del'].forEach(function(method) {
      return appExports[method] = function(pattern, callback) {
        return routes.push([method, pattern, callback]);
      };
    });
    appExports.router = function() {
      var router;
      router = new Router(serverMock);
      routes.forEach(function(_arg) {
        var callback, method, pattern;
        method = _arg[0], pattern = _arg[1], callback = _arg[2];
        return router._route(method, pattern, function(req, res, next) {
          var body, k, model, page, params, query, url, v, _ref;
          model = req.model || store.createModel();
          page = new Page(view, res, model);
          params = (url = req.url, body = req.body, query = req.query, req);
          _ref = req.params;
          for (k in _ref) {
            v = _ref[k];
            params[k] = v;
          }
          return callback(page, model, params, next);
        });
      });
      return router.middleware;
    };
    view._derbyOptions = this.options;
    view._appFilename = appModule.filename;
    view.render();
    return appExports;
  },
  createStatic: function(root) {
    return new Static(root);
  },
  createStore: function() {
    var app, args, last, options, store, _i, _len;
    args = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
    last = args[args.length - 1];
    if (!last.view) {
      options = args.pop();
    }
    store = racer.createStore(options);
    for (_i = 0, _len = args.length; _i < _len; _i++) {
      app = args[_i];
      app._setStore(store);
    }
    return store;
  },
  session: racer.session
};

==> derby-0.1.3.tgz: package/lib/derby.js <==
var Page, Router, Static, View, derby, fs, loader, racer, serverMock;
var __slice = Array.prototype.slice;

racer = require('racer');

View = require('./View.server');

loader = require('./loader');

Router = require('express/lib/router');

fs = require('fs');

serverMock = {
  enabled: function() {
    return false;
  }
};

Page = function(view, res, model) {
  this.view = view;
  this.res = res;
  this.model = model;
};

Page.prototype = {
  render: function(ctx, status) {
    return this.view.render(this.res, this.model, ctx, status);
  },
  redirect: function(url, status) {
    return this.res.redirect(url, status);
  }
};

Static = function(root) {
  this.root = root;
  this.views = {};
};

Static.prototype = {
  render: function(name, res, model, ctx, status) {
    var view;
    if (!(view = this.views[name])) {
      view = this.views[name] = new View;
      view._root = this.root;
      view._clientName = name;
    }
    return view.render(res, model, ctx, status, true);
  }
};

derby = module.exports = {
  options: {},
  configure: function(options) {
    this.options = options;
  },
  createApp: function(appModule) {
    var appExports, routes, session, setStore, store, view;
    appExports = appModule.exports;
    appExports.view = view = new View;
    appExports.render = function(res, model, ctx, status) {
      return view.render(res, model, ctx, status);
    };
    appExports.ready = function() {};
    store = null;
    session = null;
    appExports._setStore = setStore = function(_store) {
      if (session != null) session._setStore(_store);
      return store = _store;
    };
    appExports.createStore = function(options) {
      return setStore(racer.createStore(options));
    };
    appExports.session = function() {
      return session = racer.session(store);
    };
    routes = [];
    ['get', 'post', 'put', 'del'].forEach(function(method) {
      return appExports[method] = function(pattern, callback) {
        return routes.push([method, pattern, callback]);
      };
    });
    appExports.router = function() {
      var router;
      router = new Router(serverMock);
      routes.forEach(function(_arg) {
        var callback, method, pattern;
        method = _arg[0], pattern = _arg[1], callback = _arg[2];
        return router._route(method, pattern, function(req, res, next) {
          var body, k, model, page, params, query, url, v, _ref;
          model = req.model || store.createModel();
          page = new Page(view, res, model);
          params = (url = req.url, body = req.body, query = req.query, req);
          _ref = req.params;
          for (k in _ref) {
            v = _ref[k];
            params[k] = v;
          }
          return callback(page, model, params, next);
        });
      });
      return router.middleware;
    };
    view._derbyOptions = this.options;
    view._appFilename = appModule.filename;
    view.render();
    return appExports;
  },
  createStatic: function(root) {
    return new Static(root);
  },
  createStore: function() {
    var app, args, last, options, store, _i, _len;
    args = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
    last = args[args.length - 1];
    if (!last.view) options = args.pop();
    store = racer.createStore(options);
    for (_i = 0, _len = args.length; _i < _len; _i++) {
      app = args[_i];
      app._setStore(store);
    }
    return store;
  },
  session: racer.session
};

Object.defineProperty(derby, 'version', {
  get: function() {
    return JSON.parse(fs.readFileSync(__dirname + '/../package.json', 'utf8')).version;
  }
});
